@@ -30,7 +30,20 @@ class ListCommand(BaseListCommand, Lister):
 
     def take_action(self, parsed_args):
         client = get_client(parsed_args)
-        values = client.configuration.list()['values']
+        marker = parsed_args.marker if parsed_args.marker else None
+        limit = parsed_args.limit if parsed_args.limit else None
+
+        result = client.configuration.list(marker=marker, limit=limit)
+
+        values = result['values']
+        metadata = result['metadata']
+        limit, marker, next_marker = metadata['limit'], metadata['marker'], \
+            metadata['next_marker']
+
+        # Hack
+        parsed_args.returned_limit = limit
+        parsed_args.returned_marker = marker
+        parsed_args.returned_next_marker = next_marker
 
         result = [(value['id'], value['value'])
                   for value in values]
